--  *********************************************************************
--  Update Database Script
--  *********************************************************************
--  Change Log: upgrade.changelog-up-to-0.20.0.xml
--  Ran at: 25/06/2024 20:29
--  Against: root@jdbc:mariadb://mariadb/squashtest
--  Liquibase version: 4.17.2
--  *********************************************************************

--  Lock Database
UPDATE DATABASECHANGELOGLOCK SET `LOCKED` = 1, LOCKEDBY = 'runner-yfpexrfv8-project-33554404-concurrent-0-kowxep0y (100.64.33.125)', LOCKGRANTED = NOW() WHERE ID = 1 AND `LOCKED` = 0;

--  Changeset ../tm/tm.changelog-0.19.0.xml::tm-0.19.0.01::ramoussou
--  We have to set campaign_ID and Test_plan_order to "true" to let hibernate persist new items
CREATE TABLE CAMPAIGN_TEST_PLAN_ITEM (CTPI_ID BIGINT AUTO_INCREMENT NOT NULL COMMENT 'clé primaire du test plan. Devrait être autogénérée.', CAMPAIGN_ID BIGINT NULL COMMENT 'cle etrangere vers CAMPAIGN', TEST_CASE_ID BIGINT NOT NULL COMMENT 'cle etrangere vers TEST_CASE', USER_ID BIGINT NULL COMMENT 'Id de l''utilisateur assigné a ce cas de test reférenncé', TEST_PLAN_ORDER INT NULL COMMENT 'numéro d''ordre d''une execution dans la liste des test plans d''une itération.', CONSTRAINT PK_CAMPAIGN_TEST_PLAN_ITEM PRIMARY KEY (CTPI_ID), CONSTRAINT fk_camp_tp_campaign FOREIGN KEY (CAMPAIGN_ID) REFERENCES CAMPAIGN(CLN_ID), CONSTRAINT fk_camp_tp_user FOREIGN KEY (USER_ID) REFERENCES CORE_USER(ID), CONSTRAINT fk_camp_tp_testcase FOREIGN KEY (TEST_CASE_ID) REFERENCES TEST_CASE(TCLN_ID));

CREATE INDEX idx_camptestplan ON CAMPAIGN_TEST_PLAN_ITEM(CTPI_ID);

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.19.0.01', 'ramoussou', '../tm/tm.changelog-0.19.0.xml', NOW(), 1, '8:ad46b14330533a66289110f0391edec8', 'createTable tableName=CAMPAIGN_TEST_PLAN_ITEM; createIndex indexName=idx_camptestplan, tableName=CAMPAIGN_TEST_PLAN_ITEM', 'We have to set campaign_ID and Test_plan_order to "true" to let hibernate persist new items', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.19.0.xml::tm-0.19.0.02::ramoussou
--  Migrates data from unordered campaign test plan table to ordered test plan table.
--  	 		Items which references (soft) deleted test cases and which should not be in the table are not migrated
insert into CAMPAIGN_TEST_PLAN_ITEM (CAMPAIGN_ID, TEST_CASE_ID)
			select tp.CAMPAIGN_ID, tp.TEST_CASE_ID
			from CAMPAIGN_TEST_PLAN tp
				inner join TEST_CASE_LIBRARY_NODE tc on tc.TCLN_ID = tp.TEST_CASE_ID
			where tc.DELETED_ON is null;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.19.0.02', 'ramoussou', '../tm/tm.changelog-0.19.0.xml', NOW(), 2, '8:ab232337d4ea59b9517418f86ce936e8', 'sql', 'Migrates data from unordered campaign test plan table to ordered test plan table.
	 		Items which references (soft) deleted test cases and which should not be in the table are not migrated', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.19.0.xml::tm-0.19.0.03::ramoussou
--  Calculate and insert and add Not null constraint on order for Campaign Test Plan For H2
--  Changeset ../tm/tm.changelog-0.19.0.xml::tm-0.19.0.04::ramoussou
--  Calculate and insert and add Not null constraint on order for Campaign Test Plan for myssql
CREATE TEMPORARY TABLE `MIGRATION_CAMPAIGN_TEST_PLAN` (
			`TEST_PLAN_ORDER` BIGINT NULL DEFAULT NULL,
			`CAMPAIGN_ID` BIGINT NULL DEFAULT NULL,
			`TEST_CASE_ID` BIGINT NULL DEFAULT NULL,
			`DUMMY` BIGINT NULL DEFAULT NULL
			);

insert into MIGRATION_CAMPAIGN_TEST_PLAN (TEST_PLAN_ORDER, CAMPAIGN_ID, TEST_CASE_ID, DUMMY)
			select if(@prevcamp=CAMPAIGN_ID, @rownum:=@rownum+1, @rownum:=0) TEST_PLAN_ORDER, CAMPAIGN_ID, TEST_CASE_ID, (@prevcamp:=CAMPAIGN_ID)
			from CAMPAIGN_TEST_PLAN_ITEM ctp, (SELECT @rownum:=0) r, (SELECT @prevcamp:=0) c
			order by CAMPAIGN_ID;

update CAMPAIGN_TEST_PLAN_ITEM citp set TEST_PLAN_ORDER =
				(select mctp.TEST_PLAN_ORDER from MIGRATION_CAMPAIGN_TEST_PLAN mctp
				where mctp.CAMPAIGN_ID = citp.CAMPAIGN_ID
				and mctp.TEST_CASE_ID = citp.TEST_CASE_ID);

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.19.0.04', 'ramoussou', '../tm/tm.changelog-0.19.0.xml', NOW(), 3, '8:8a22997a222ba3d4795b8d3205bb3b3a', 'sql', 'Calculate and insert and add Not null constraint on order for Campaign Test Plan for myssql', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.19.0.xml::tm-0.19.0.04-postgres::mpagnon
--  Calculate and insert and add Not null constraint on order for Campaign Test Plan for postgresql
--  Changeset ../tm/tm.changelog-0.19.0.xml::tm-0.19.0.06::ramoussou
--  Drop table CAMPAIGN_TEST_PLAN
DROP TABLE CAMPAIGN_TEST_PLAN;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.19.0.06', 'ramoussou', '../tm/tm.changelog-0.19.0.xml', NOW(), 4, '8:1513496bc6e7e42d55289448d23a5ce1', 'dropTable tableName=CAMPAIGN_TEST_PLAN', 'Drop table CAMPAIGN_TEST_PLAN', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.19.0.xml::tm-0.19.0.07::ramoussou
ALTER TABLE ITEM_TEST_PLAN ADD USER_ID BIGINT NULL COMMENT 'Id de l''utilisateur assigné a ce cas de test reférenncé';

ALTER TABLE ITEM_TEST_PLAN ADD CONSTRAINT fk_itertestplan_user FOREIGN KEY (USER_ID) REFERENCES CORE_USER (ID);

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.19.0.07', 'ramoussou', '../tm/tm.changelog-0.19.0.xml', NOW(), 5, '8:46ca6a04862330a49c334f13e897abf8', 'addColumn tableName=ITEM_TEST_PLAN', '', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.20.0.xml::tm-0.20.0.01::gfouquet
--  The PROJECT_ID foreign key in TEST_CASE_LIBRARY is useless, the useful one is in the PROJECT table
ALTER TABLE TEST_CASE_LIBRARY DROP FOREIGN KEY fk_tcl_project;

ALTER TABLE TEST_CASE_LIBRARY DROP COLUMN PROJECT_ID;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.20.0.01', 'gfouquet', '../tm/tm.changelog-0.20.0.xml', NOW(), 6, '8:54c3ebe91db56778cde9e87d8d4d77db', 'dropForeignKeyConstraint baseTableName=TEST_CASE_LIBRARY, constraintName=fk_tcl_project; dropColumn columnName=PROJECT_ID, tableName=TEST_CASE_LIBRARY', 'The PROJECT_ID foreign key in TEST_CASE_LIBRARY is useless, the useful one is in the PROJECT table', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.20.0.xml::tm-0.20.0.02::gfouquet
--  The PROJECT_ID foreign key in REQUIREMENT_LIBRARY is useless, the useful one is in the PROJECT table
ALTER TABLE REQUIREMENT_LIBRARY DROP FOREIGN KEY fk_rl_project;

ALTER TABLE REQUIREMENT_LIBRARY DROP COLUMN PROJECT_ID;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.20.0.02', 'gfouquet', '../tm/tm.changelog-0.20.0.xml', NOW(), 7, '8:f0ef7eed1568f2722690dc4270632b72', 'dropForeignKeyConstraint baseTableName=REQUIREMENT_LIBRARY, constraintName=fk_rl_project; dropColumn columnName=PROJECT_ID, tableName=REQUIREMENT_LIBRARY', 'The PROJECT_ID foreign key in REQUIREMENT_LIBRARY is useless, the useful one is in the PROJECT table', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.20.0.xml::tm-0.20.0.03::gfouquet
--  The PROJECT_ID foreign key in CAMPAIGN_LIBRARY is useless, the useful one is in the PROJECT table
ALTER TABLE CAMPAIGN_LIBRARY DROP FOREIGN KEY fk_cl_project;

ALTER TABLE CAMPAIGN_LIBRARY DROP COLUMN PROJECT_ID;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.20.0.03', 'gfouquet', '../tm/tm.changelog-0.20.0.xml', NOW(), 8, '8:7f782a7a9ea306ffaa6cf58433ab21cb', 'dropForeignKeyConstraint baseTableName=CAMPAIGN_LIBRARY, constraintName=fk_cl_project; dropColumn columnName=PROJECT_ID, tableName=CAMPAIGN_LIBRARY', 'The PROJECT_ID foreign key in CAMPAIGN_LIBRARY is useless, the useful one is in the PROJECT table', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.20.0.xml::tm-0.20.0.05::bsiri
ALTER TABLE EXECUTION MODIFY ISSUE_LIST_ID BIGINT NULL;

ALTER TABLE EXECUTION_STEP MODIFY ISSUE_LIST_ID BIGINT NULL;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.20.0.05', 'bsiri', '../tm/tm.changelog-0.20.0.xml', NOW(), 9, '8:0969ff7e63508bf077c77d3161274cc6', 'dropNotNullConstraint columnName=ISSUE_LIST_ID, tableName=EXECUTION; dropNotNullConstraint columnName=ISSUE_LIST_ID, tableName=EXECUTION_STEP', '', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.20.0.xml::tm-0.20.0.07::bsiri
--  add an ondelete set null to the fk campaign test plan item  -> core user
ALTER TABLE CAMPAIGN_TEST_PLAN_ITEM DROP FOREIGN KEY fk_camp_tp_user;

ALTER TABLE CAMPAIGN_TEST_PLAN_ITEM ADD CONSTRAINT fk_camp_tp_user FOREIGN KEY (USER_ID) REFERENCES CORE_USER (ID) ON DELETE SET NULL;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.20.0.07', 'bsiri', '../tm/tm.changelog-0.20.0.xml', NOW(), 10, '8:2a0ba7e062dba6f26d6b3a92d7583ea5', 'dropForeignKeyConstraint baseTableName=CAMPAIGN_TEST_PLAN_ITEM, constraintName=fk_camp_tp_user; addForeignKeyConstraint baseTableName=CAMPAIGN_TEST_PLAN_ITEM, constraintName=fk_camp_tp_user, referencedTableName=CORE_USER', 'add an ondelete set null to the fk campaign test plan item  -> core user', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.20.0.xml::tm-0.20.0.40::gfouquet
--  Replace the ATTACHMENT_LIST_CONTENT table by a FK in ATTACHMENT
ALTER TABLE ATTACHMENT ADD ATTACHMENT_LIST_ID BIGINT NULL;

update ATTACHMENT a set ATTACHMENT_LIST_ID = (select AL_ID from ATTACHMENT_LIST_CONTENT alc where
			alc.ATTACHMENT_ID = a.ATTACHMENT_ID);

DROP TABLE ATTACHMENT_LIST_CONTENT;

ALTER TABLE ATTACHMENT ADD CONSTRAINT fk_attachment_att_list FOREIGN KEY (ATTACHMENT_LIST_ID) REFERENCES ATTACHMENT_LIST (ATTACHMENT_LIST_ID);

ALTER TABLE ATTACHMENT MODIFY ATTACHMENT_LIST_ID BIGINT NOT NULL;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.20.0.40', 'gfouquet', '../tm/tm.changelog-0.20.0.xml', NOW(), 11, '8:bba76e65c8a5a74eba758644e9772461', 'addColumn tableName=ATTACHMENT; sql; dropTable tableName=ATTACHMENT_LIST_CONTENT; addForeignKeyConstraint baseTableName=ATTACHMENT, constraintName=fk_attachment_att_list, referencedTableName=ATTACHMENT_LIST; addNotNullConstraint columnName=ATTACHM...', 'Replace the ATTACHMENT_LIST_CONTENT table by a FK in ATTACHMENT', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.20.0.xml::tm-0.20.0.41::gfouquet
--  Replace the ISSUE_LIST_CONTENT table by a FK in ISSUE
ALTER TABLE ISSUE ADD ISSUE_LIST_ID BIGINT NULL COMMENT 'References the list of issue to which an issue belongs';

update ISSUE i set ISSUE_LIST_ID = (select ISSUE_LIST_ID from ISSUE_LIST_CONTENT ilc where ilc.ISSUE_ID =
			i.ISSUE_ID);

DROP TABLE ISSUE_LIST_CONTENT;

ALTER TABLE ISSUE ADD CONSTRAINT fk_issue_issue_list FOREIGN KEY (ISSUE_LIST_ID) REFERENCES ISSUE_LIST (ISSUE_LIST_ID);

ALTER TABLE ISSUE MODIFY ISSUE_LIST_ID BIGINT NOT NULL;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.20.0.41', 'gfouquet', '../tm/tm.changelog-0.20.0.xml', NOW(), 12, '8:725e99af4ddae5c100b82592a8690917', 'addColumn tableName=ISSUE; sql; dropTable tableName=ISSUE_LIST_CONTENT; addForeignKeyConstraint baseTableName=ISSUE, constraintName=fk_issue_issue_list, referencedTableName=ISSUE_LIST; addNotNullConstraint columnName=ISSUE_LIST_ID, tableName=ISSUE', 'Replace the ISSUE_LIST_CONTENT table by a FK in ISSUE', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../tm/tm.changelog-0.20.0.xml::tm-0.20.0.42::gfouquet
--  Rename ITEM_TEST_PLAN into ITERATION_TEST_PLAN_ITEM
ALTER TABLE ITEM_TEST_PLAN RENAME ITERATION_TEST_PLAN_ITEM;

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('tm-0.20.0.42', 'gfouquet', '../tm/tm.changelog-0.20.0.xml', NOW(), 13, '8:fbfd69634e8ded997ef0474b29ac9013', 'renameTable newTableName=ITERATION_TEST_PLAN_ITEM, oldTableName=ITEM_TEST_PLAN', 'Rename ITEM_TEST_PLAN into ITERATION_TEST_PLAN_ITEM', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../core/core.changelog-0.20.0.xml::core-0.20.0.01::ramoussou
--  Creation of a new table CORE_CONFIG containing Application configuration
CREATE TABLE CORE_CONFIG (STR_KEY VARCHAR(255) NOT NULL COMMENT 'Configuration Key', VALUE TEXT NULL COMMENT 'Configuration value', CONSTRAINT PK_CORE_CONFIG PRIMARY KEY (STR_KEY));

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('core-0.20.0.01', 'ramoussou', '../core/core.changelog-0.20.0.xml', NOW(), 14, '8:2cd6847655e834de27ab193dd6dce68e', 'createTable tableName=CORE_CONFIG', 'Creation of a new table CORE_CONFIG containing Application configuration', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Changeset ../core/core.changelog-0.20.0.xml::core-0.20.0.02::gfouquet
--  Default welcome message
insert into CORE_CONFIG (STR_KEY, VALUE) values ('WELCOME_MESSAGE', '<p><span style="color:#ff0000;">The administrator default login is <strong>admin/admin</strong> (you can change this password in the &quot;<em>My account (admin)</em>&quot; menu).</span></p><p>Go to the &quot;<em>Administration&quot;</em> menu (in the upper right corner) to create new users and projects, or change this default home message.</p><p>&nbsp;</p>');

INSERT INTO DATABASECHANGELOG (ID, AUTHOR, FILENAME, DATEEXECUTED, ORDEREXECUTED, MD5SUM, `DESCRIPTION`, COMMENTS, EXECTYPE, CONTEXTS, LABELS, LIQUIBASE, DEPLOYMENT_ID) VALUES ('core-0.20.0.02', 'gfouquet', '../core/core.changelog-0.20.0.xml', NOW(), 15, '8:ef79d86b09bba9709eec0c58596b246a', 'sql', 'Default welcome message', 'EXECUTED', NULL, NULL, '4.17.2', '9340183767');

--  Release Database Lock
UPDATE DATABASECHANGELOGLOCK SET `LOCKED` = 0, LOCKEDBY = NULL, LOCKGRANTED = NULL WHERE ID = 1;

